@@ -8,8 +8,27 @@ import pypsa
 from numpy import genfromtxt
 from colorama import Fore, Back, Style
 from termcolor import colored
+from past.builtins import execfile
+import os
+# from <FOLDER NAME> import <NAME of .py>
+# For PYPI
+from faifah import ieee_test_system
+# from faifah import load_profile
+# from faifah import dummy
+
+
+# -- NOTE The variables can be imported under Class 
+
+
+#For local run
+# import ieee_test_system
+# import load_profile
+# import dummy.plk
+
+import os
+
+
 
-from ieee_test_system import load_IEEE5, load_IEEE33, load_IEEE69
 
 # Require :
 # - numpy
@@ -22,24 +41,40 @@ class Grid:
 
     def __init__( self, nbus, NETWORK_ = '', LINE_DATA_CSV='', BUS_DATA_CSV='', MVA_base = np.nan , KV_base = np.nan, SLACK_POS = np.nan ):
 
+
+        
+
+        
+
         if len(LINE_DATA_CSV) != 0 and len(BUS_DATA_CSV) != 0  :
             
             self.load_data,  self.line_data, self.nBus = self.query_csv( nbus, LINE_DATA_CSV, BUS_DATA_CSV)
             
         elif NETWORK_ == 'IEEE5' :
             print('IEEE5-bus test distribution system')
-            self.load_data,  self.line_data, self.nBus = load_IEEE5()
+            self.load_data,  self.line_data, self.nBus = ieee_test_system.load_IEEE5()
         
         elif NETWORK_ == 'IEEE33' :
             print('IEEE33-bus test distribution system')
-            self.load_data,  self.line_data, self.nBus = load_IEEE33()
+            self.load_data,  self.line_data, self.nBus = ieee_test_system.load_IEEE33()
         
         elif NETWORK_ == 'IEEE69' :
             print('IEEE69-bus test distribution system')
-            self.load_data,  self.line_data, self.nBus = load_IEEE69()
+            self.load_data,  self.line_data, self.nBus = ieee_test_system.load_IEEE69()
 
         else :
             print('Invalid')
+
+
+        # print("=======Load profile=============")
+
+        # # execfile( 'dummy.pkl' )
+        # # self.run_file('dummy.pkl')
+        # # exec(compile(open('dummy.pkl').read()))
+
+        # self.load_profile   = pd.read_pickle('dummy.pkl')
+        # print(self.load_profile.head())
+        # print("===============================")
         
         self.slack_bus_pos  = SLACK_POS 
         self.MVA_base       = MVA_base   
@@ -53,7 +88,6 @@ class Grid:
         self.total_kVAr_demand  = self.load_data.Q_KVAr.sum()
         self.total_kVAr_supply  = 0
 
-
         self.total_kW_loss = 0
         self.total_kVAr_loss = 0
 
@@ -88,7 +122,11 @@ class Grid:
 
         self.org_network  = deepcopy(self.network)
  
-    
+    def run_file(self, path):
+        return exec(open(path).read())
+
+
+
 
     
     def query_csv(self, nbus, LINE_DATA_CSV, BUS_DATA_CSV):
@@ -1078,15 +1116,31 @@ class Grid:
 
         return abs(systemObj.V[:])
 
+
 if __name__ == "__main__" :
 
+        
+    # For local run
+
+    # import ieee_test_system
+    # import load_profile
+
+
+    
+    
+    # print('in main')
+    # import os
+    # print("PYTHONPATH:", os.environ.get('PYTHONPATH'))
+    # print("PATH:", os.environ.get('PATH'))
+    
 #Query from CSV
-    MVA_base = 100.0 # Defining the Base-MVA
-    KV_base = 100 #KV 
-    nBus = 5
-    SLACK_POS = 1
-    NETWORK_ = ''
-    IEEE5_csv = Grid( nBus, NETWORK_, 'faifah/5BusTest-line.csv', 'faifah/5BusTest-load.csv', MVA_base ,  KV_base, SLACK_POS)
+
+    # MVA_base = 100.0 # Defining the Base-MVA
+    # KV_base = 100 #KV 
+    # nBus = 5
+    # SLACK_POS = 1
+    # NETWORK_ = ''
+    # IEEE5_csv = Grid( nBus, NETWORK_, 'faifah/5BusTest-line.csv', 'faifah/5BusTest-load.csv', MVA_base ,  KV_base, SLACK_POS)
     # # ( self, nbus, NETWORK_ = '', LINE_DATA_CSV='', BUS_DATA_CSV='', MVA_base = np.nan , KV_base = np.nan, SLACK_POS = np.nan ):
 
 
@@ -1098,9 +1152,10 @@ if __name__ == "__main__" :
     # Gen_name = "G2"
     # IEEE5.addGen(BusID, P_KW, Q_KVAr, Control,Gen_name)
     # IEEE5.LoadFlow()
-    IEEE5_csv.Report()
+    # IEEE5_csv.Report()
 
 #Query from package
+
     NETWORK_ = 'IEEE5'
     MVA_base = 100.0 # Defining the Base-MVA
     KV_base = 100 #KV 
@@ -1109,6 +1164,16 @@ if __name__ == "__main__" :
 
     IEEE5 = Grid( nBus, NETWORK_, '', '', MVA_base ,  KV_base, SLACK_POS )
     IEEE5.Report()
+    # import os
+
+
+    # print(loadProfile_2017.csv loadProfile_2017.csv)
+    # print('File name :    ', os.path.basename( "loadProfile_2017.csv"))
+    # print('Directory Name:     ', os.path.dirname("loadProfile_2017.csv"))
+    # print( IEEE5.df_loadProfile.head() )
+
+
+
 
     # print( IEEE5.line_data )
     # print( IEEE5.load_data )
